package org.xiss.examples;

import net.sf.xanswer.indexing.IndexException;

import org.xiss.index.IXissIndex;
import org.xiss.index.XissIndexFactory;
import org.xiss.query.Chunk;
import org.xiss.query.IQuery;
import org.xiss.query.IResult;
import org.xiss.query.QueryParseException;
import org.xiss.query.XissQueryFactory;

public class RunQuery {
	public static void main(String[] args) {
		if (args.length != 2) {
			System.out.println("Usage: RunQuery <index> <query>");
			System.out
					.println("Runs a regular XPath query on an existing index");
			System.out
					.println("index - directory containing the queried index");
			System.out.println("query - a regular XPath expression");
		}

		long start, end;
		
		start = System.currentTimeMillis();
		
		XissIndexFactory factory = XissIndexFactory.newInstance();
		IXissIndex index = null;
		try {
			index = factory.open(args[0]);
		} catch (IndexException e) {
			System.out.println("Couldn't open index: " + e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
			return;
		}

		end = System.currentTimeMillis();
		System.out.println("Index loaded, took "+(end-start)+"ms");
		
		start = System.currentTimeMillis();
		XissQueryFactory queryFactory = XissQueryFactory.newInstance();
		IQuery query = null;
		try {
			query = queryFactory.parse(args[1]);
		} catch (QueryParseException e) {
			System.out.println("Query parse error: " + e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
			return;
		}
		end = System.currentTimeMillis();
		System.out.println("Query parsed, took "+(end-start)+"ms");

		start = System.currentTimeMillis();
		
		IResult res;
		try {
			res = index.query(query);
		} catch (IndexException e) {
			System.out.println("Index error during query run: "
					+ e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
			return;
		}

		end = System.currentTimeMillis();
		
		System.out.println("Complete, query took "+(end-start)+"ms");
		System.out.println("Result: ");
		for (Chunk chunk : res.getChunks()) {
			System.out.println(chunk);
		}

		
		try {
			index.close();
		} catch (IndexException e) {
		}
	}
}
