package org.xiss.examples;

import java.util.ArrayList;
import java.util.List;

import net.sf.xanswer.indexing.IndexException;

import org.xiss.index.IXissIndex;
import org.xiss.index.XissIndexFactory;
import org.xiss.query.IQuery;
import org.xiss.query.IXissOperation;
import org.xiss.query.XissQueryFactory;
import org.xiss.query.operations.JoinOperation;
import org.xiss.query.operations.SelectOperation;

public class RunQueryPlanDemo {
	public static void main(String[] args) {
		if (args.length != 3) {
			System.out
					.println("Usage: QueryFromScriptDemo <index> <firstElement> <secondElement>");
			System.out
					.println("Demonstrates the possibility to create queries directly from their "
							+ "plan without parsing the query.");
			System.out
					.println("Finds all occurences of secondElement that are included in an element"
							+ " of type firstElement");
			System.out
					.println("index - directory containing the index to be queried");
			System.out
					.println("firstElement, secondElement - names of elements to be found");
		}

		String indexLocation = args[0];
		String firstElement = args[1];
		String secondElement = args[2];

		System.out.println("Reading index from " + indexLocation);
		System.out.println("Searching for " + secondElement + " in "
				+ firstElement);

		IXissIndex index = null;
		try {
			index = XissIndexFactory.newInstance().open(indexLocation);
		} catch (IndexException e) {
			System.out.println("Error opening index: " + e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
			return;
		}

		List<IXissOperation> plan = new ArrayList<IXissOperation>();
		plan.add(new SelectOperation(firstElement, false));
		plan.add(new SelectOperation(secondElement, false));
		plan.add(new JoinOperation(0, false));

		XissQueryFactory queryFactory = XissQueryFactory.newInstance();
		IQuery query = queryFactory.createFromPlan(plan);
		System.out.println("Query plan: " + query);
		System.out.println("Result: ");
		try {
			System.out.println(index.query(query));
		} catch (IndexException e) {
			System.out.println("Index error during query run: "
					+ e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
			return;
		}

		try {
			index.close();
		} catch (IndexException e) {
			System.out.println("Error closing index: " + e.getMessage());
			System.out.println("Error stack trace follows: ");
			e.printStackTrace(System.out);
		}
	}
}
