package org.xiss.index;

import java.io.Serializable;

/**
 * An abstract class being the base for both element/attribute index entries and
 * structure index entries. This interface by itself is useless.
 */
public abstract class IndexEntry implements Serializable {
	/**
	 * Denotes a 'null' value for node identifiers, for instance a node with no
	 * parent will have ParentId = NONE.
	 */
	public static final int NONE = -1;

	/**
	 * ID of the entry (number of its corresponding element in preorder
	 * traversal)
	 */
	public int Id;

	/**
	 * Get size of the entry (total count of its subnodes)
	 */
	public int Size;

	/**
	 * Get id of the first node not contained in this one. Is equivalent to
	 * Id+Size.
	 */
	public final int getNextId() {
		return Id + Size;
	}

	/**
	 * Get ID of the parent of this node. If this is the root node, the return
	 * value is {@link #NONE}
	 */
	public int ParentId;

	/**
	 * Get ID of the value of this node (key for value table) For attributes
	 * this means value of the attribute, for text nodes this means their text
	 * value, otherwise the value is {@link #NONE}.
	 */
	public int ValueId;
}
