package org.xiss.map;

import net.sf.xanswer.storage.map.PersistentException;

/**
 * A generic B-Tree that can be used as a regular map, however supposedly
 * persistent.
 */
public interface IBTree<K, V> extends Iterable<KeyValuePair<K, V>> {
	/**
	 * Check whether the given key is contained in the tree
	 * 
	 * @throws PersistentException
	 */
	public boolean containsKey(K key) throws PersistentException;

	/**
	 * Get the value corresponding to the given key, or null if the key is not
	 * present in the tree
	 * 
	 * @throws PersistentException
	 */
	public V get(K key) throws PersistentException;

	/**
	 * Change or set the value corresponding to the given key
	 * 
	 * @throws PersistentException
	 */
	public void put(K key, V value) throws PersistentException;

	/**
	 * Clear the tree
	 */
	public void clear();

	/**
	 * Prepare the tree for operations
	 * 
	 * @throws PersistentException
	 */
	public void open() throws PersistentException;

	/**
	 * Close the tree: flush all caches, save tree data, dispose occupied
	 * resources etc.
	 * 
	 * @throws PersistentException
	 */
	public void close() throws PersistentException;

	/**
	 * Delete the tree
	 * 
	 * @throws PersistentException
	 */
	public void drop() throws PersistentException;
}
