package org.xiss.query;

import org.xiss.index.ElementIndexEntry;

/**
 * A chunk is a segment of a path in a document defined by node ID's of its root
 * and deep part. For instance, in a path
 * /public/commerce/products/gadgets/screwdriver/@color the path from 'commerce'
 * to 'screwdriver' will be represented as a chunk having root pointing to
 * 'commerce' and 'deep' pointing to 'screwdriver'.
 */
public class Chunk {
	public ElementIndexEntry Start, End;

	public Chunk(ElementIndexEntry start, ElementIndexEntry end) {
		Start = start;
		End = end;
	}

	public static int compare(Chunk a, Chunk b, boolean sortStartNotEnd) {
		if (sortStartNotEnd) {
			return a.Start.Id - b.Start.Id;
		}
		return a.End.Id - b.End.Id;
	}

	public boolean equals(Object x) {
		if (x == this) {
			return true;
		}
		if (!(x instanceof Chunk)) {
			return false;
		}
		Chunk chunk = (Chunk) x;
		return (Start.equals(chunk.Start) && End.equals(chunk.End));
	}

	public String toString() {
		return Start.Id + ".." + End.Id;
	}
}
