package org.xiss.query;

import java.util.List;

import org.xiss.query.impl.XissQuery;
import org.xiss.query.impl.XissQueryParser;

/**
 * Factory for creating queries either by parsing regular XPath expressions or
 * directly from query plan
 */
public class XissQueryFactory implements IQueryFactory {
	private XissQueryFactory() {
	}

	public static XissQueryFactory newInstance() {
		return new XissQueryFactory();
	}

	/**
	 * Parse a regular XPath expression.
	 * 
	 * Grammar: Query = GlobalPath | (Query) | QueryUnion QueryUnion = Query '|'
	 * Query GlobalPath = AbsPath | AnyLocPath AbsPath = '/' Path AnyLocPath =
	 * Path | '//' Path Path = PathChunk ['/' Path] PathChunk = SingleChunk ['['
	 * Predicate ']'] ['*'] SingleChunk = '_' | {Name} | '@'{Name} | '('
	 * PathChunkInBraces ')' PathChunkInBraces = PathChunk | PathChunk '|'
	 * PathChunk Predicate = NodePredicate | AttributePredicate NodePredicate =
	 * {Name} AttributePredicate = '@' {Name} ['=' '"' {AttributeValue} '"']
	 * 
	 * Name = regex(text()|([^_][a-zA-Z0-9_]*)) AttributeValue = regex([^"]*)
	 * 
	 */
	public IQuery parse(String query) throws QueryParseException {
		return new XissQueryParser(query).parse();
	}

	/**
	 * Create a query as a sequence of operations
	 */
	public IQuery createFromPlan(List<IXissOperation> plan) {
		return new XissQuery(plan);
	}
}
