package org.xiss.query.impl.ast;

import java.util.List;

import org.xiss.query.IXissOperation;
import org.xiss.query.operations.KleeneClosureOperation;

public class PathChunkNode extends AstNode {
	private boolean myIsKleeneClosure;

	private PredicateNode myPredicate;

	private AstNode myCore;

	public PathChunkNode(AstNode core, PredicateNode predicate,
			boolean isKleeneClosure) {
		myCore = core;
		setPredicate(predicate);
		setKleeneClosure(isKleeneClosure);
	}

	public void preprocessForGeneration() {
		if (myPredicate != null) {
			myPredicate.preprocessForGeneration();
		}
		if (myCore != null) {
			myCore.preprocessForGeneration();
		}
	}

	public void generateCodeTo(List<IXissOperation> script) {
		myCore.generateCodeTo(script);
		if (getPredicate() != null) {
			getPredicate().generateCodeTo(script);
		}
		if (isKleeneClosure()) {
			script.add(new KleeneClosureOperation());
		}
	}

	public void setCore(AstNode core) {
		myCore = core;
	}

	public AstNode getCore() {
		return myCore;
	}

	public void setPredicate(PredicateNode predicate) {
		myPredicate = predicate;
	}

	public PredicateNode getPredicate() {
		return myPredicate;
	}

	public void setKleeneClosure(boolean isKleeneClosure) {
		myIsKleeneClosure = isKleeneClosure;
	}

	public boolean isKleeneClosure() {
		return myIsKleeneClosure;
	}
}
