package org.xiss.query.operations;

import java.util.List;
import java.util.Stack;

import net.sf.xanswer.indexing.IndexException;

import org.xiss.index.ElementIndexEntry;
import org.xiss.index.IXissIndex;
import org.xiss.query.Chunk;
import org.xiss.query.IResult;
import org.xiss.query.IXissOperation;
import org.xiss.query.impl.ChunkList;

/**
 * Selects all elements or attributes with the given name
 */
public class SelectOperation implements IXissOperation {
	private String myNodeName;

	private boolean myIsAttributeNotElement;

	public SelectOperation(String nodeName, boolean isAttributeNotElement) {
		myNodeName = nodeName;
		myIsAttributeNotElement = isAttributeNotElement;
	}

	public void run(IXissIndex index, Stack<IResult> context)
			throws IndexException {
		ChunkList nodes = new ChunkList();
		nodes.setRootSorted();
		nodes.setDeepSorted();
		List<? extends ElementIndexEntry> entries = (isAttributeNotElement()) ? index
				.getAttributeIndexEntriesByNid(index.getNidByName(myNodeName))
				: index.getElementIndexEntriesByNid(index
						.getNidByName(myNodeName));
		for (ElementIndexEntry entry : entries) {
			nodes.addChunk(new Chunk(entry, entry));
		}
		context.push(nodes);
	}

	public String toString() {
		if (myIsAttributeNotElement) {
			return "SELECT(@" + myNodeName + ")";
		} else {
			return "SELECT(" + myNodeName + ")";
		}
	}

	public boolean isAttributeNotElement() {
		return myIsAttributeNotElement;
	}
}
